@@ -76,7 +76,7 @@ class AuthGoogleMiddleware(object):
         @wraps(start_response)
         def wrapper(status, headers, exc_info=None):
             if email:
-                headers.append(('X-Google-Account', email))
+                headers.append(('X-Google-Account', email.encode('ascii')))
             return start_response(status, headers, exc_info)
         return wrapper
 
